Module: Sai::Decorator::Delegator Abstract Private

Included in:
Sai
Defined in:
lib/sai/decorator/delegator.rb

Overview

This module is part of a private API. You should avoid using this module if possible, as it may be removed or be changed in the future.

This module is abstract.

Include in a class or module to provide method delegation to the Sai::Decorator class

Provides method delegation to the Sai::Decorator class for classes or modules that include it

Author:

Since:

  • 0.4.0

Instance Method Summary collapse

Instance Method Details

#with_mode(mode) ⇒ Decorator

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Apply a specific color mode to the Sai::Decorator instance

Parameters:

  • mode (Integer) —

    the color mode to use

Returns:

  • (Decorator) —

    a new instance of Decorator with the applied color mode

Author:

Since:

  • 0.4.0



74
75
76
# File 'lib/sai/decorator/delegator.rb', line 74

def with_mode(mode)
  Decorator.new(mode:)
end