Module: Sai::Decorator::NamedColors Abstract Private
- Included in:
- Sai::Decorator
- Defined in:
- lib/sai/decorator/named_colors.rb
Overview
This module is part of a private API. You should avoid using this module if possible, as it may be removed or be changed in the future.
This module is abstract.
This module is meant to be included in the Sai::Decorator class to provide named color methods
Note:
For each named color, two methods are dynamically generated:
- color_name - Applies the color to the foreground
- on_color_name - Applies the color to the backgroundAll color methods return Sai::Decorator
Named color methods for the Sai::Decorator class
Defined Under Namespace
Modules: ClassMethods
Class Method Summary collapse
-
.included(base) ⇒ void
private
Inject ClassMethods into the including class.
Class Method Details
.included(base) ⇒ void
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
This method returns an undefined value.
Inject ClassMethods into the including class
32 33 34 |
# File 'lib/sai/decorator/named_colors.rb', line 32 def self.included(base) base.extend(ClassMethods) end |